@@ -3,7 +3,7 @@ package App::CekBpom;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-09-02'; # DATE
 our $DIST = 'App-CekBpom'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -41,7 +41,12 @@ _
         search_type => {
             schema => ['str*', in=>[sort keys %search_types]],
             default => 'nama_produk',
-            cmdline_aliases => {t=>{}},
+            cmdline_aliases => {
+                t=>{},
+                (
+                    map { my $t = $_; ($t => {is_flag=>1, summary=>"Shortcut for --search-type=$_", code=>sub {$_[0]{search_type} = $t} }) } keys %search_types,
+                ),
+            },
         },
         query => {
             schema =>  'str*',
@@ -143,7 +148,7 @@ App::CekBpom - Check BPOM products via the command-line (CLI interface for cekbp
 
 =head1 VERSION
 
-This document describes version 0.001 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-02.
+This document describes version 0.002 of App::CekBpom (from Perl distribution App-CekBpom), released on 2020-09-02.
 
 =head1 DESCRIPTION
 
